<img src="https://github.com/orchardbirds/bokbokbok/raw/main/docs/img/bokbokbok.png" width="120" align="right">


# bokbokbok

## Overview

**bokbokbok** is a python package that enables you to use Custom Loss Functions and Evaluation Metrics for XGBoost and LightGBM.
Main features:

- Weighted Cross Entropy
- Focal Loss
- Squared Log Error
- Log Cosh Loss

## Installation

```bash
pip install bokbokbok
```

## Documentation

The documentation can [be found here.](https://orchardbirds.github.io/)

## Contributing

To learn more about making a contribution to bokbokbok, please see CONTRIBUTING.md.